# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .purge_web_app_acceleration_cache_details import PurgeWebAppAccelerationCacheDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PurgeEntireWebAppAccelerationCacheDetails(PurgeWebAppAccelerationCacheDetails):
    """
    Clears all resources from the cache of the WebAppAcceleration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PurgeEntireWebAppAccelerationCacheDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.waa.models.PurgeEntireWebAppAccelerationCacheDetails.purge_type` attribute
        of this class is ``ENTIRE_CACHE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param purge_type:
            The value to assign to the purge_type property of this PurgeEntireWebAppAccelerationCacheDetails.
            Allowed values for this property are: "ENTIRE_CACHE"
        :type purge_type: str

        """
        self.swagger_types = {
            'purge_type': 'str'
        }

        self.attribute_map = {
            'purge_type': 'purgeType'
        }

        self._purge_type = None
        self._purge_type = 'ENTIRE_CACHE'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class IngressListenerTlsConfig(object):
    """
    TLS enforcement config for the ingress listener.
    """

    #: A constant which can be used with the mode property of a IngressListenerTlsConfig.
    #: This constant has a value of "DISABLED"
    MODE_DISABLED = "DISABLED"

    #: A constant which can be used with the mode property of a IngressListenerTlsConfig.
    #: This constant has a value of "PERMISSIVE"
    MODE_PERMISSIVE = "PERMISSIVE"

    #: A constant which can be used with the mode property of a IngressListenerTlsConfig.
    #: This constant has a value of "TLS"
    MODE_TLS = "TLS"

    #: A constant which can be used with the mode property of a IngressListenerTlsConfig.
    #: This constant has a value of "MUTUAL_TLS"
    MODE_MUTUAL_TLS = "MUTUAL_TLS"

    def __init__(self, **kwargs):
        """
        Initializes a new IngressListenerTlsConfig object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param mode:
            The value to assign to the mode property of this IngressListenerTlsConfig.
            Allowed values for this property are: "DISABLED", "PERMISSIVE", "TLS", "MUTUAL_TLS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type mode: str

        :param server_certificate:
            The value to assign to the server_certificate property of this IngressListenerTlsConfig.
        :type server_certificate: oci.service_mesh.models.TlsCertificate

        :param client_validation:
            The value to assign to the client_validation property of this IngressListenerTlsConfig.
        :type client_validation: oci.service_mesh.models.IngressListenerClientValidationConfig

        """
        self.swagger_types = {
            'mode': 'str',
            'server_certificate': 'TlsCertificate',
            'client_validation': 'IngressListenerClientValidationConfig'
        }

        self.attribute_map = {
            'mode': 'mode',
            'server_certificate': 'serverCertificate',
            'client_validation': 'clientValidation'
        }

        self._mode = None
        self._server_certificate = None
        self._client_validation = None

    @property
    def mode(self):
        """
        **[Required]** Gets the mode of this IngressListenerTlsConfig.
        DISABLED: Connection can only be plaintext.
        PERMISSIVE: Connection can be either plaintext or TLS/mTLS. If the clientValidation.trustedCaBundle property is configured for the listener, mTLS is performed and the client's certificates are validated by the gateway.
        TLS: Connection can only be TLS.
        MUTUAL_TLS: Connection can only be MTLS.

        Allowed values for this property are: "DISABLED", "PERMISSIVE", "TLS", "MUTUAL_TLS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The mode of this IngressListenerTlsConfig.
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """
        Sets the mode of this IngressListenerTlsConfig.
        DISABLED: Connection can only be plaintext.
        PERMISSIVE: Connection can be either plaintext or TLS/mTLS. If the clientValidation.trustedCaBundle property is configured for the listener, mTLS is performed and the client's certificates are validated by the gateway.
        TLS: Connection can only be TLS.
        MUTUAL_TLS: Connection can only be MTLS.


        :param mode: The mode of this IngressListenerTlsConfig.
        :type: str
        """
        allowed_values = ["DISABLED", "PERMISSIVE", "TLS", "MUTUAL_TLS"]
        if not value_allowed_none_or_none_sentinel(mode, allowed_values):
            mode = 'UNKNOWN_ENUM_VALUE'
        self._mode = mode

    @property
    def server_certificate(self):
        """
        Gets the server_certificate of this IngressListenerTlsConfig.

        :return: The server_certificate of this IngressListenerTlsConfig.
        :rtype: oci.service_mesh.models.TlsCertificate
        """
        return self._server_certificate

    @server_certificate.setter
    def server_certificate(self, server_certificate):
        """
        Sets the server_certificate of this IngressListenerTlsConfig.

        :param server_certificate: The server_certificate of this IngressListenerTlsConfig.
        :type: oci.service_mesh.models.TlsCertificate
        """
        self._server_certificate = server_certificate

    @property
    def client_validation(self):
        """
        Gets the client_validation of this IngressListenerTlsConfig.

        :return: The client_validation of this IngressListenerTlsConfig.
        :rtype: oci.service_mesh.models.IngressListenerClientValidationConfig
        """
        return self._client_validation

    @client_validation.setter
    def client_validation(self, client_validation):
        """
        Sets the client_validation of this IngressListenerTlsConfig.

        :param client_validation: The client_validation of this IngressListenerTlsConfig.
        :type: oci.service_mesh.models.IngressListenerClientValidationConfig
        """
        self._client_validation = client_validation

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .payment_detail import PaymentDetail
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OtherPaymentDetail(PaymentDetail):
    """
    Other Payment related details
    """

    #: A constant which can be used with the credit_card_type property of a OtherPaymentDetail.
    #: This constant has a value of "VISA"
    CREDIT_CARD_TYPE_VISA = "VISA"

    #: A constant which can be used with the credit_card_type property of a OtherPaymentDetail.
    #: This constant has a value of "AMEX"
    CREDIT_CARD_TYPE_AMEX = "AMEX"

    #: A constant which can be used with the credit_card_type property of a OtherPaymentDetail.
    #: This constant has a value of "MASTERCARD"
    CREDIT_CARD_TYPE_MASTERCARD = "MASTERCARD"

    #: A constant which can be used with the credit_card_type property of a OtherPaymentDetail.
    #: This constant has a value of "DISCOVER"
    CREDIT_CARD_TYPE_DISCOVER = "DISCOVER"

    #: A constant which can be used with the credit_card_type property of a OtherPaymentDetail.
    #: This constant has a value of "JCB"
    CREDIT_CARD_TYPE_JCB = "JCB"

    #: A constant which can be used with the credit_card_type property of a OtherPaymentDetail.
    #: This constant has a value of "DINER"
    CREDIT_CARD_TYPE_DINER = "DINER"

    #: A constant which can be used with the credit_card_type property of a OtherPaymentDetail.
    #: This constant has a value of "ELO"
    CREDIT_CARD_TYPE_ELO = "ELO"

    def __init__(self, **kwargs):
        """
        Initializes a new OtherPaymentDetail object with values from keyword arguments. The default value of the :py:attr:`~oci.osp_gateway.models.OtherPaymentDetail.payment_method` attribute
        of this class is ``OTHER`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_paid_on:
            The value to assign to the time_paid_on property of this OtherPaymentDetail.
        :type time_paid_on: datetime

        :param paid_by:
            The value to assign to the paid_by property of this OtherPaymentDetail.
        :type paid_by: str

        :param payment_method:
            The value to assign to the payment_method property of this OtherPaymentDetail.
            Allowed values for this property are: "CREDIT_CARD", "PAYPAL", "OTHER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type payment_method: str

        :param amount_paid:
            The value to assign to the amount_paid property of this OtherPaymentDetail.
        :type amount_paid: float

        :param echeck_routing:
            The value to assign to the echeck_routing property of this OtherPaymentDetail.
        :type echeck_routing: str

        :param name_on_card:
            The value to assign to the name_on_card property of this OtherPaymentDetail.
        :type name_on_card: str

        :param credit_card_type:
            The value to assign to the credit_card_type property of this OtherPaymentDetail.
            Allowed values for this property are: "VISA", "AMEX", "MASTERCARD", "DISCOVER", "JCB", "DINER", "ELO", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type credit_card_type: str

        :param last_digits:
            The value to assign to the last_digits property of this OtherPaymentDetail.
        :type last_digits: str

        :param time_expiration:
            The value to assign to the time_expiration property of this OtherPaymentDetail.
        :type time_expiration: datetime

        """
        self.swagger_types = {
            'time_paid_on': 'datetime',
            'paid_by': 'str',
            'payment_method': 'str',
            'amount_paid': 'float',
            'echeck_routing': 'str',
            'name_on_card': 'str',
            'credit_card_type': 'str',
            'last_digits': 'str',
            'time_expiration': 'datetime'
        }

        self.attribute_map = {
            'time_paid_on': 'timePaidOn',
            'paid_by': 'paidBy',
            'payment_method': 'paymentMethod',
            'amount_paid': 'amountPaid',
            'echeck_routing': 'echeckRouting',
            'name_on_card': 'nameOnCard',
            'credit_card_type': 'creditCardType',
            'last_digits': 'lastDigits',
            'time_expiration': 'timeExpiration'
        }

        self._time_paid_on = None
        self._paid_by = None
        self._payment_method = None
        self._amount_paid = None
        self._echeck_routing = None
        self._name_on_card = None
        self._credit_card_type = None
        self._last_digits = None
        self._time_expiration = None
        self._payment_method = 'OTHER'

    @property
    def echeck_routing(self):
        """
        Gets the echeck_routing of this OtherPaymentDetail.
        Last four routing digits of the card


        :return: The echeck_routing of this OtherPaymentDetail.
        :rtype: str
        """
        return self._echeck_routing

    @echeck_routing.setter
    def echeck_routing(self, echeck_routing):
        """
        Sets the echeck_routing of this OtherPaymentDetail.
        Last four routing digits of the card


        :param echeck_routing: The echeck_routing of this OtherPaymentDetail.
        :type: str
        """
        self._echeck_routing = echeck_routing

    @property
    def name_on_card(self):
        """
        Gets the name_on_card of this OtherPaymentDetail.
        Name on the echeck card


        :return: The name_on_card of this OtherPaymentDetail.
        :rtype: str
        """
        return self._name_on_card

    @name_on_card.setter
    def name_on_card(self, name_on_card):
        """
        Sets the name_on_card of this OtherPaymentDetail.
        Name on the echeck card


        :param name_on_card: The name_on_card of this OtherPaymentDetail.
        :type: str
        """
        self._name_on_card = name_on_card

    @property
    def credit_card_type(self):
        """
        Gets the credit_card_type of this OtherPaymentDetail.
        Echeck card type

        Allowed values for this property are: "VISA", "AMEX", "MASTERCARD", "DISCOVER", "JCB", "DINER", "ELO", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The credit_card_type of this OtherPaymentDetail.
        :rtype: str
        """
        return self._credit_card_type

    @credit_card_type.setter
    def credit_card_type(self, credit_card_type):
        """
        Sets the credit_card_type of this OtherPaymentDetail.
        Echeck card type


        :param credit_card_type: The credit_card_type of this OtherPaymentDetail.
        :type: str
        """
        allowed_values = ["VISA", "AMEX", "MASTERCARD", "DISCOVER", "JCB", "DINER", "ELO"]
        if not value_allowed_none_or_none_sentinel(credit_card_type, allowed_values):
            credit_card_type = 'UNKNOWN_ENUM_VALUE'
        self._credit_card_type = credit_card_type

    @property
    def last_digits(self):
        """
        Gets the last_digits of this OtherPaymentDetail.
        Last four digits of the card


        :return: The last_digits of this OtherPaymentDetail.
        :rtype: str
        """
        return self._last_digits

    @last_digits.setter
    def last_digits(self, last_digits):
        """
        Sets the last_digits of this OtherPaymentDetail.
        Last four digits of the card


        :param last_digits: The last_digits of this OtherPaymentDetail.
        :type: str
        """
        self._last_digits = last_digits

    @property
    def time_expiration(self):
        """
        Gets the time_expiration of this OtherPaymentDetail.
        Expired date of the echeck card


        :return: The time_expiration of this OtherPaymentDetail.
        :rtype: datetime
        """
        return self._time_expiration

    @time_expiration.setter
    def time_expiration(self, time_expiration):
        """
        Sets the time_expiration of this OtherPaymentDetail.
        Expired date of the echeck card


        :param time_expiration: The time_expiration of this OtherPaymentDetail.
        :type: datetime
        """
        self._time_expiration = time_expiration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .change_em_warehouse_compartment_details import ChangeEmWarehouseCompartmentDetails
from .create_em_warehouse_details import CreateEmWarehouseDetails
from .em_instances_details import EmInstancesDetails
from .em_warehouse import EmWarehouse
from .em_warehouse_collection import EmWarehouseCollection
from .em_warehouse_summary import EmWarehouseSummary
from .etl_run_collection import EtlRunCollection
from .etl_run_summary import EtlRunSummary
from .resource_usage import ResourceUsage
from .update_em_warehouse_details import UpdateEmWarehouseDetails
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary
from .work_request_summary_collection import WorkRequestSummaryCollection

# Maps type names to classes for em_warehouse services.
em_warehouse_type_mapping = {
    "ChangeEmWarehouseCompartmentDetails": ChangeEmWarehouseCompartmentDetails,
    "CreateEmWarehouseDetails": CreateEmWarehouseDetails,
    "EmInstancesDetails": EmInstancesDetails,
    "EmWarehouse": EmWarehouse,
    "EmWarehouseCollection": EmWarehouseCollection,
    "EmWarehouseSummary": EmWarehouseSummary,
    "EtlRunCollection": EtlRunCollection,
    "EtlRunSummary": EtlRunSummary,
    "ResourceUsage": ResourceUsage,
    "UpdateEmWarehouseDetails": UpdateEmWarehouseDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary,
    "WorkRequestSummaryCollection": WorkRequestSummaryCollection
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .template import Template
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QuotaTemplate(Template):
    """
    Quota template for governance rule.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new QuotaTemplate object with values from keyword arguments. The default value of the :py:attr:`~oci.governance_rules_control_plane.models.QuotaTemplate.type` attribute
        of this class is ``QUOTA`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this QuotaTemplate.
            Allowed values for this property are: "QUOTA", "TAG", "ALLOWED_REGIONS"
        :type type: str

        :param display_name:
            The value to assign to the display_name property of this QuotaTemplate.
        :type display_name: str

        :param description:
            The value to assign to the description property of this QuotaTemplate.
        :type description: str

        :param statements:
            The value to assign to the statements property of this QuotaTemplate.
        :type statements: list[str]

        """
        self.swagger_types = {
            'type': 'str',
            'display_name': 'str',
            'description': 'str',
            'statements': 'list[str]'
        }

        self.attribute_map = {
            'type': 'type',
            'display_name': 'displayName',
            'description': 'description',
            'statements': 'statements'
        }

        self._type = None
        self._display_name = None
        self._description = None
        self._statements = None
        self._type = 'QUOTA'

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this QuotaTemplate.
        Display name of the quota resource.


        :return: The display_name of this QuotaTemplate.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this QuotaTemplate.
        Display name of the quota resource.


        :param display_name: The display_name of this QuotaTemplate.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this QuotaTemplate.
        Description of the quota resource.


        :return: The description of this QuotaTemplate.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this QuotaTemplate.
        Description of the quota resource.


        :param description: The description of this QuotaTemplate.
        :type: str
        """
        self._description = description

    @property
    def statements(self):
        """
        **[Required]** Gets the statements of this QuotaTemplate.
        List of quota statements.


        :return: The statements of this QuotaTemplate.
        :rtype: list[str]
        """
        return self._statements

    @statements.setter
    def statements(self, statements):
        """
        Sets the statements of this QuotaTemplate.
        List of quota statements.


        :param statements: The statements of this QuotaTemplate.
        :type: list[str]
        """
        self._statements = statements

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlTuningAdvisorTaskSummaryReportIndexFindingSummary(object):
    """
    A summary for all the index findings in a SQL Tuning Advisor task. Includes the index's hash value, table name, schema, index name, reference count and index columns
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SqlTuningAdvisorTaskSummaryReportIndexFindingSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param index_hash_value:
            The value to assign to the index_hash_value property of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :type index_hash_value: int

        :param index_name:
            The value to assign to the index_name property of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :type index_name: str

        :param table_name:
            The value to assign to the table_name property of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :type table_name: str

        :param schema:
            The value to assign to the schema property of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :type schema: str

        :param reference_count:
            The value to assign to the reference_count property of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :type reference_count: int

        :param index_columns:
            The value to assign to the index_columns property of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :type index_columns: list[str]

        """
        self.swagger_types = {
            'index_hash_value': 'int',
            'index_name': 'str',
            'table_name': 'str',
            'schema': 'str',
            'reference_count': 'int',
            'index_columns': 'list[str]'
        }

        self.attribute_map = {
            'index_hash_value': 'indexHashValue',
            'index_name': 'indexName',
            'table_name': 'tableName',
            'schema': 'schema',
            'reference_count': 'referenceCount',
            'index_columns': 'indexColumns'
        }

        self._index_hash_value = None
        self._index_name = None
        self._table_name = None
        self._schema = None
        self._reference_count = None
        self._index_columns = None

    @property
    def index_hash_value(self):
        """
        **[Required]** Gets the index_hash_value of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        Numerical representation of the index.


        :return: The index_hash_value of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :rtype: int
        """
        return self._index_hash_value

    @index_hash_value.setter
    def index_hash_value(self, index_hash_value):
        """
        Sets the index_hash_value of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        Numerical representation of the index.


        :param index_hash_value: The index_hash_value of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :type: int
        """
        self._index_hash_value = index_hash_value

    @property
    def index_name(self):
        """
        **[Required]** Gets the index_name of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        Name of the index.


        :return: The index_name of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :rtype: str
        """
        return self._index_name

    @index_name.setter
    def index_name(self, index_name):
        """
        Sets the index_name of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        Name of the index.


        :param index_name: The index_name of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :type: str
        """
        self._index_name = index_name

    @property
    def table_name(self):
        """
        **[Required]** Gets the table_name of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        Table's name related to the index.


        :return: The table_name of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        """
        Sets the table_name of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        Table's name related to the index.


        :param table_name: The table_name of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :type: str
        """
        self._table_name = table_name

    @property
    def schema(self):
        """
        **[Required]** Gets the schema of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        Schema related to the index.


        :return: The schema of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :rtype: str
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """
        Sets the schema of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        Schema related to the index.


        :param schema: The schema of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :type: str
        """
        self._schema = schema

    @property
    def reference_count(self):
        """
        **[Required]** Gets the reference_count of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        The number of times the index is referenced within the SQL Tuning advisor task findings.


        :return: The reference_count of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :rtype: int
        """
        return self._reference_count

    @reference_count.setter
    def reference_count(self, reference_count):
        """
        Sets the reference_count of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        The number of times the index is referenced within the SQL Tuning advisor task findings.


        :param reference_count: The reference_count of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :type: int
        """
        self._reference_count = reference_count

    @property
    def index_columns(self):
        """
        **[Required]** Gets the index_columns of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        Columns of the index.


        :return: The index_columns of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :rtype: list[str]
        """
        return self._index_columns

    @index_columns.setter
    def index_columns(self, index_columns):
        """
        Sets the index_columns of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        Columns of the index.


        :param index_columns: The index_columns of this SqlTuningAdvisorTaskSummaryReportIndexFindingSummary.
        :type: list[str]
        """
        self._index_columns = index_columns

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .mapped_secret import MappedSecret
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VaultMappedSecret(MappedSecret):
    """
    Mapped secret stored in OCI vault used in the firewall policy rules.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VaultMappedSecret object with values from keyword arguments. The default value of the :py:attr:`~oci.network_firewall.models.VaultMappedSecret.source` attribute
        of this class is ``OCI_VAULT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source:
            The value to assign to the source property of this VaultMappedSecret.
        :type source: str

        :param type:
            The value to assign to the type property of this VaultMappedSecret.
            Allowed values for this property are: "SSL_INBOUND_INSPECTION", "SSL_FORWARD_PROXY"
        :type type: str

        :param vault_secret_id:
            The value to assign to the vault_secret_id property of this VaultMappedSecret.
        :type vault_secret_id: str

        :param version_number:
            The value to assign to the version_number property of this VaultMappedSecret.
        :type version_number: int

        """
        self.swagger_types = {
            'source': 'str',
            'type': 'str',
            'vault_secret_id': 'str',
            'version_number': 'int'
        }

        self.attribute_map = {
            'source': 'source',
            'type': 'type',
            'vault_secret_id': 'vaultSecretId',
            'version_number': 'versionNumber'
        }

        self._source = None
        self._type = None
        self._vault_secret_id = None
        self._version_number = None
        self._source = 'OCI_VAULT'

    @property
    def vault_secret_id(self):
        """
        **[Required]** Gets the vault_secret_id of this VaultMappedSecret.
        OCID for the Vault Secret to be used.


        :return: The vault_secret_id of this VaultMappedSecret.
        :rtype: str
        """
        return self._vault_secret_id

    @vault_secret_id.setter
    def vault_secret_id(self, vault_secret_id):
        """
        Sets the vault_secret_id of this VaultMappedSecret.
        OCID for the Vault Secret to be used.


        :param vault_secret_id: The vault_secret_id of this VaultMappedSecret.
        :type: str
        """
        self._vault_secret_id = vault_secret_id

    @property
    def version_number(self):
        """
        **[Required]** Gets the version_number of this VaultMappedSecret.
        Version number of the secret to be used.


        :return: The version_number of this VaultMappedSecret.
        :rtype: int
        """
        return self._version_number

    @version_number.setter
    def version_number(self, version_number):
        """
        Sets the version_number of this VaultMappedSecret.
        Version number of the secret to be used.


        :param version_number: The version_number of this VaultMappedSecret.
        :type: int
        """
        self._version_number = version_number

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .operator import Operator
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Pivot(Operator):
    """
    Pivot operator has one input and one output. Pivot operator takes group by columns, a pivot key with values and aggregations. Output is the pivoted table.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Pivot object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.Pivot.model_type` attribute
        of this class is ``PIVOT_OPERATOR`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this Pivot.
            Allowed values for this property are: "SOURCE_OPERATOR", "FILTER_OPERATOR", "JOINER_OPERATOR", "AGGREGATOR_OPERATOR", "PROJECTION_OPERATOR", "TARGET_OPERATOR", "FLATTEN_OPERATOR", "DISTINCT_OPERATOR", "SORT_OPERATOR", "UNION_OPERATOR", "INTERSECT_OPERATOR", "MINUS_OPERATOR", "MERGE_OPERATOR", "FUNCTION_OPERATOR", "SPLIT_OPERATOR", "START_OPERATOR", "END_OPERATOR", "PIPELINE_OPERATOR", "TASK_OPERATOR", "EXPRESSION_OPERATOR", "LOOKUP_OPERATOR", "PIVOT_OPERATOR"
        :type model_type: str

        :param key:
            The value to assign to the key property of this Pivot.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this Pivot.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this Pivot.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this Pivot.
        :type name: str

        :param description:
            The value to assign to the description property of this Pivot.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this Pivot.
        :type object_version: int

        :param input_ports:
            The value to assign to the input_ports property of this Pivot.
        :type input_ports: list[oci.data_integration.models.InputPort]

        :param output_ports:
            The value to assign to the output_ports property of this Pivot.
        :type output_ports: list[oci.data_integration.models.TypedObject]

        :param object_status:
            The value to assign to the object_status property of this Pivot.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this Pivot.
        :type identifier: str

        :param parameters:
            The value to assign to the parameters property of this Pivot.
        :type parameters: list[oci.data_integration.models.Parameter]

        :param op_config_values:
            The value to assign to the op_config_values property of this Pivot.
        :type op_config_values: oci.data_integration.models.ConfigValues

        :param group_by_columns:
            The value to assign to the group_by_columns property of this Pivot.
        :type group_by_columns: oci.data_integration.models.DynamicProxyField

        :param pivot_keys:
            The value to assign to the pivot_keys property of this Pivot.
        :type pivot_keys: oci.data_integration.models.PivotKeys

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'input_ports': 'list[InputPort]',
            'output_ports': 'list[TypedObject]',
            'object_status': 'int',
            'identifier': 'str',
            'parameters': 'list[Parameter]',
            'op_config_values': 'ConfigValues',
            'group_by_columns': 'DynamicProxyField',
            'pivot_keys': 'PivotKeys'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'input_ports': 'inputPorts',
            'output_ports': 'outputPorts',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'parameters': 'parameters',
            'op_config_values': 'opConfigValues',
            'group_by_columns': 'groupByColumns',
            'pivot_keys': 'pivotKeys'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._input_ports = None
        self._output_ports = None
        self._object_status = None
        self._identifier = None
        self._parameters = None
        self._op_config_values = None
        self._group_by_columns = None
        self._pivot_keys = None
        self._model_type = 'PIVOT_OPERATOR'

    @property
    def group_by_columns(self):
        """
        Gets the group_by_columns of this Pivot.

        :return: The group_by_columns of this Pivot.
        :rtype: oci.data_integration.models.DynamicProxyField
        """
        return self._group_by_columns

    @group_by_columns.setter
    def group_by_columns(self, group_by_columns):
        """
        Sets the group_by_columns of this Pivot.

        :param group_by_columns: The group_by_columns of this Pivot.
        :type: oci.data_integration.models.DynamicProxyField
        """
        self._group_by_columns = group_by_columns

    @property
    def pivot_keys(self):
        """
        Gets the pivot_keys of this Pivot.

        :return: The pivot_keys of this Pivot.
        :rtype: oci.data_integration.models.PivotKeys
        """
        return self._pivot_keys

    @pivot_keys.setter
    def pivot_keys(self, pivot_keys):
        """
        Sets the pivot_keys of this Pivot.

        :param pivot_keys: The pivot_keys of this Pivot.
        :type: oci.data_integration.models.PivotKeys
        """
        self._pivot_keys = pivot_keys

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LicenseRecord(object):
    """
    License record summary.
    """

    #: A constant which can be used with the lifecycle_state property of a LicenseRecord.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a LicenseRecord.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a LicenseRecord.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the license_unit property of a LicenseRecord.
    #: This constant has a value of "OCPU"
    LICENSE_UNIT_OCPU = "OCPU"

    #: A constant which can be used with the license_unit property of a LicenseRecord.
    #: This constant has a value of "NAMED_USER_PLUS"
    LICENSE_UNIT_NAMED_USER_PLUS = "NAMED_USER_PLUS"

    #: A constant which can be used with the license_unit property of a LicenseRecord.
    #: This constant has a value of "PROCESSORS"
    LICENSE_UNIT_PROCESSORS = "PROCESSORS"

    def __init__(self, **kwargs):
        """
        Initializes a new LicenseRecord object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this LicenseRecord.
        :type id: str

        :param product_license_id:
            The value to assign to the product_license_id property of this LicenseRecord.
        :type product_license_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this LicenseRecord.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this LicenseRecord.
        :type display_name: str

        :param product_id:
            The value to assign to the product_id property of this LicenseRecord.
        :type product_id: str

        :param license_count:
            The value to assign to the license_count property of this LicenseRecord.
        :type license_count: int

        :param expiration_date:
            The value to assign to the expiration_date property of this LicenseRecord.
        :type expiration_date: datetime

        :param support_end_date:
            The value to assign to the support_end_date property of this LicenseRecord.
        :type support_end_date: datetime

        :param is_unlimited:
            The value to assign to the is_unlimited property of this LicenseRecord.
        :type is_unlimited: bool

        :param is_perpetual:
            The value to assign to the is_perpetual property of this LicenseRecord.
        :type is_perpetual: bool

        :param time_created:
            The value to assign to the time_created property of this LicenseRecord.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this LicenseRecord.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this LicenseRecord.
            Allowed values for this property are: "ACTIVE", "INACTIVE", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param license_unit:
            The value to assign to the license_unit property of this LicenseRecord.
            Allowed values for this property are: "OCPU", "NAMED_USER_PLUS", "PROCESSORS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type license_unit: str

        :param product_license:
            The value to assign to the product_license property of this LicenseRecord.
        :type product_license: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this LicenseRecord.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this LicenseRecord.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this LicenseRecord.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'product_license_id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'product_id': 'str',
            'license_count': 'int',
            'expiration_date': 'datetime',
            'support_end_date': 'datetime',
            'is_unlimited': 'bool',
            'is_perpetual': 'bool',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'license_unit': 'str',
            'product_license': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'product_license_id': 'productLicenseId',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'product_id': 'productId',
            'license_count': 'licenseCount',
            'expiration_date': 'expirationDate',
            'support_end_date': 'supportEndDate',
            'is_unlimited': 'isUnlimited',
            'is_perpetual': 'isPerpetual',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'license_unit': 'licenseUnit',
            'product_license': 'productLicense',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._product_license_id = None
        self._compartment_id = None
        self._display_name = None
        self._product_id = None
        self._license_count = None
        self._expiration_date = None
        self._support_end_date = None
        self._is_unlimited = None
        self._is_perpetual = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._license_unit = None
        self._product_license = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this LicenseRecord.
        The license record `OCID`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this LicenseRecord.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LicenseRecord.
        The license record `OCID`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this LicenseRecord.
        :type: str
        """
        self._id = id

    @property
    def product_license_id(self):
        """
        Gets the product_license_id of this LicenseRecord.
        The product license `OCID`__ with which the license record is associated.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The product_license_id of this LicenseRecord.
        :rtype: str
        """
        return self._product_license_id

    @product_license_id.setter
    def product_license_id(self, product_license_id):
        """
        Sets the product_license_id of this LicenseRecord.
        The product license `OCID`__ with which the license record is associated.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param product_license_id: The product_license_id of this LicenseRecord.
        :type: str
        """
        self._product_license_id = product_license_id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this LicenseRecord.
        The compartment `OCID`__ where the license record is created.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this LicenseRecord.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this LicenseRecord.
        The compartment `OCID`__ where the license record is created.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this LicenseRecord.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this LicenseRecord.
        The license record display name. Avoid entering confidential information.


        :return: The display_name of this LicenseRecord.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this LicenseRecord.
        The license record display name. Avoid entering confidential information.


        :param display_name: The display_name of this LicenseRecord.
        :type: str
        """
        self._display_name = display_name

    @property
    def product_id(self):
        """
        Gets the product_id of this LicenseRecord.
        The license record product ID.


        :return: The product_id of this LicenseRecord.
        :rtype: str
        """
        return self._product_id

    @product_id.setter
    def product_id(self, product_id):
        """
        Sets the product_id of this LicenseRecord.
        The license record product ID.


        :param product_id: The product_id of this LicenseRecord.
        :type: str
        """
        self._product_id = product_id

    @property
    def license_count(self):
        """
        Gets the license_count of this LicenseRecord.
        The number of license units added by the user for the given license record.
        Default 1


        :return: The license_count of this LicenseRecord.
        :rtype: int
        """
        return self._license_count

    @license_count.setter
    def license_count(self, license_count):
        """
        Sets the license_count of this LicenseRecord.
        The number of license units added by the user for the given license record.
        Default 1


        :param license_count: The license_count of this LicenseRecord.
        :type: int
        """
        self._license_count = license_count

    @property
    def expiration_date(self):
        """
        Gets the expiration_date of this LicenseRecord.
        The license record end date in `RFC 3339`__
        date format.
        Example: `2018-09-12`

        __ https://tools.ietf.org/html/rfc3339


        :return: The expiration_date of this LicenseRecord.
        :rtype: datetime
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """
        Sets the expiration_date of this LicenseRecord.
        The license record end date in `RFC 3339`__
        date format.
        Example: `2018-09-12`

        __ https://tools.ietf.org/html/rfc3339


        :param expiration_date: The expiration_date of this LicenseRecord.
        :type: datetime
        """
        self._expiration_date = expiration_date

    @property
    def support_end_date(self):
        """
        Gets the support_end_date of this LicenseRecord.
        The license record support end date in `RFC 3339`__
        date format.
        Example: `2018-09-12`

        __ https://tools.ietf.org/html/rfc3339


        :return: The support_end_date of this LicenseRecord.
        :rtype: datetime
        """
        return self._support_end_date

    @support_end_date.setter
    def support_end_date(self, support_end_date):
        """
        Sets the support_end_date of this LicenseRecord.
        The license record support end date in `RFC 3339`__
        date format.
        Example: `2018-09-12`

        __ https://tools.ietf.org/html/rfc3339


        :param support_end_date: The support_end_date of this LicenseRecord.
        :type: datetime
        """
        self._support_end_date = support_end_date

    @property
    def is_unlimited(self):
        """
        **[Required]** Gets the is_unlimited of this LicenseRecord.
        Specifies if the license count is unlimited.


        :return: The is_unlimited of this LicenseRecord.
        :rtype: bool
        """
        return self._is_unlimited

    @is_unlimited.setter
    def is_unlimited(self, is_unlimited):
        """
        Sets the is_unlimited of this LicenseRecord.
        Specifies if the license count is unlimited.


        :param is_unlimited: The is_unlimited of this LicenseRecord.
        :type: bool
        """
        self._is_unlimited = is_unlimited

    @property
    def is_perpetual(self):
        """
        **[Required]** Gets the is_perpetual of this LicenseRecord.
        Specifies if the license record term is perpertual.


        :return: The is_perpetual of this LicenseRecord.
        :rtype: bool
        """
        return self._is_perpetual

    @is_perpetual.setter
    def is_perpetual(self, is_perpetual):
        """
        Sets the is_perpetual of this LicenseRecord.
        Specifies if the license record term is perpertual.


        :param is_perpetual: The is_perpetual of this LicenseRecord.
        :type: bool
        """
        self._is_perpetual = is_perpetual

    @property
    def time_created(self):
        """
        Gets the time_created of this LicenseRecord.
        The time the license record was created. An `RFC 3339`__-formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this LicenseRecord.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this LicenseRecord.
        The time the license record was created. An `RFC 3339`__-formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this LicenseRecord.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this LicenseRecord.
        The time the license record was updated. An `RFC 3339`__-formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this LicenseRecord.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this LicenseRecord.
        The time the license record was updated. An `RFC 3339`__-formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this LicenseRecord.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this LicenseRecord.
        The current license record state.

        Allowed values for this property are: "ACTIVE", "INACTIVE", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this LicenseRecord.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this LicenseRecord.
        The current license record state.


        :param lifecycle_state: The lifecycle_state of this LicenseRecord.
        :type: str
        """
        allowed_values = ["ACTIVE", "INACTIVE", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def license_unit(self):
        """
        Gets the license_unit of this LicenseRecord.
        The product license unit.

        Allowed values for this property are: "OCPU", "NAMED_USER_PLUS", "PROCESSORS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The license_unit of this LicenseRecord.
        :rtype: str
        """
        return self._license_unit

    @license_unit.setter
    def license_unit(self, license_unit):
        """
        Sets the license_unit of this LicenseRecord.
        The product license unit.


        :param license_unit: The license_unit of this LicenseRecord.
        :type: str
        """
        allowed_values = ["OCPU", "NAMED_USER_PLUS", "PROCESSORS"]
        if not value_allowed_none_or_none_sentinel(license_unit, allowed_values):
            license_unit = 'UNKNOWN_ENUM_VALUE'
        self._license_unit = license_unit

    @property
    def product_license(self):
        """
        Gets the product_license of this LicenseRecord.
        The product license name with which the license record is associated.


        :return: The product_license of this LicenseRecord.
        :rtype: str
        """
        return self._product_license

    @product_license.setter
    def product_license(self, product_license):
        """
        Sets the product_license of this LicenseRecord.
        The product license name with which the license record is associated.


        :param product_license: The product_license of this LicenseRecord.
        :type: str
        """
        self._product_license = product_license

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this LicenseRecord.
        Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this LicenseRecord.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this LicenseRecord.
        Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this LicenseRecord.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this LicenseRecord.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this LicenseRecord.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this LicenseRecord.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this LicenseRecord.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this LicenseRecord.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this LicenseRecord.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this LicenseRecord.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this LicenseRecord.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .tablespace_admin_credential_details import TablespaceAdminCredentialDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TablespaceAdminPasswordCredentialDetails(TablespaceAdminCredentialDetails):
    """
    User provides a password to be used to connect to the database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TablespaceAdminPasswordCredentialDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database_management.models.TablespaceAdminPasswordCredentialDetails.tablespace_admin_credential_type` attribute
        of this class is ``PASSWORD`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param tablespace_admin_credential_type:
            The value to assign to the tablespace_admin_credential_type property of this TablespaceAdminPasswordCredentialDetails.
            Allowed values for this property are: "SECRET", "PASSWORD"
        :type tablespace_admin_credential_type: str

        :param username:
            The value to assign to the username property of this TablespaceAdminPasswordCredentialDetails.
        :type username: str

        :param role:
            The value to assign to the role property of this TablespaceAdminPasswordCredentialDetails.
            Allowed values for this property are: "NORMAL", "SYSDBA"
        :type role: str

        :param password:
            The value to assign to the password property of this TablespaceAdminPasswordCredentialDetails.
        :type password: str

        """
        self.swagger_types = {
            'tablespace_admin_credential_type': 'str',
            'username': 'str',
            'role': 'str',
            'password': 'str'
        }

        self.attribute_map = {
            'tablespace_admin_credential_type': 'tablespaceAdminCredentialType',
            'username': 'username',
            'role': 'role',
            'password': 'password'
        }

        self._tablespace_admin_credential_type = None
        self._username = None
        self._role = None
        self._password = None
        self._tablespace_admin_credential_type = 'PASSWORD'

    @property
    def password(self):
        """
        **[Required]** Gets the password of this TablespaceAdminPasswordCredentialDetails.
        The database user's password encoded using BASE64 scheme.


        :return: The password of this TablespaceAdminPasswordCredentialDetails.
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """
        Sets the password of this TablespaceAdminPasswordCredentialDetails.
        The database user's password encoded using BASE64 scheme.


        :param password: The password of this TablespaceAdminPasswordCredentialDetails.
        :type: str
        """
        self._password = password

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FormatsForDataType(object):
    """
    A list of basic masking formats compatible with a supported data type.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FormatsForDataType object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param data_type:
            The value to assign to the data_type property of this FormatsForDataType.
        :type data_type: str

        :param masking_formats:
            The value to assign to the masking_formats property of this FormatsForDataType.
        :type masking_formats: list[oci.data_safe.models.FormatSummary]

        """
        self.swagger_types = {
            'data_type': 'str',
            'masking_formats': 'list[FormatSummary]'
        }

        self.attribute_map = {
            'data_type': 'dataType',
            'masking_formats': 'maskingFormats'
        }

        self._data_type = None
        self._masking_formats = None

    @property
    def data_type(self):
        """
        **[Required]** Gets the data_type of this FormatsForDataType.
        The data type category, which can be one of the following -
          Character - Includes CHAR, NCHAR, VARCHAR2, and NVARCHAR2
          Numeric - Includes NUMBER, FLOAT, RAW, BINARY_FLOAT, and BINARY_DOUBLE
          Date - Includes DATE and TIMESTAMP
          LOB - Includes BLOB, CLOB, and NCLOB
          All - Includes all the supported data types


        :return: The data_type of this FormatsForDataType.
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """
        Sets the data_type of this FormatsForDataType.
        The data type category, which can be one of the following -
          Character - Includes CHAR, NCHAR, VARCHAR2, and NVARCHAR2
          Numeric - Includes NUMBER, FLOAT, RAW, BINARY_FLOAT, and BINARY_DOUBLE
          Date - Includes DATE and TIMESTAMP
          LOB - Includes BLOB, CLOB, and NCLOB
          All - Includes all the supported data types


        :param data_type: The data_type of this FormatsForDataType.
        :type: str
        """
        self._data_type = data_type

    @property
    def masking_formats(self):
        """
        Gets the masking_formats of this FormatsForDataType.
        An array of the basic masking formats compatible with the data type category.


        :return: The masking_formats of this FormatsForDataType.
        :rtype: list[oci.data_safe.models.FormatSummary]
        """
        return self._masking_formats

    @masking_formats.setter
    def masking_formats(self, masking_formats):
        """
        Sets the masking_formats of this FormatsForDataType.
        An array of the basic masking formats compatible with the data type category.


        :param masking_formats: The masking_formats of this FormatsForDataType.
        :type: list[oci.data_safe.models.FormatSummary]
        """
        self._masking_formats = masking_formats

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateConfigurationSourceProviderDetails(object):
    """
    The details for updating a configuration source provider.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateConfigurationSourceProviderDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.resource_manager.models.UpdateGitlabAccessTokenConfigurationSourceProviderDetails`
        * :class:`~oci.resource_manager.models.UpdateGithubAccessTokenConfigurationSourceProviderDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateConfigurationSourceProviderDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this UpdateConfigurationSourceProviderDetails.
        :type description: str

        :param config_source_provider_type:
            The value to assign to the config_source_provider_type property of this UpdateConfigurationSourceProviderDetails.
        :type config_source_provider_type: str

        :param private_server_config_details:
            The value to assign to the private_server_config_details property of this UpdateConfigurationSourceProviderDetails.
        :type private_server_config_details: oci.resource_manager.models.PrivateServerConfigDetails

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateConfigurationSourceProviderDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateConfigurationSourceProviderDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'config_source_provider_type': 'str',
            'private_server_config_details': 'PrivateServerConfigDetails',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'config_source_provider_type': 'configSourceProviderType',
            'private_server_config_details': 'privateServerConfigDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._description = None
        self._config_source_provider_type = None
        self._private_server_config_details = None
        self._freeform_tags = None
        self._defined_tags = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['configSourceProviderType']

        if type == 'GITLAB_ACCESS_TOKEN':
            return 'UpdateGitlabAccessTokenConfigurationSourceProviderDetails'

        if type == 'GITHUB_ACCESS_TOKEN':
            return 'UpdateGithubAccessTokenConfigurationSourceProviderDetails'
        else:
            return 'UpdateConfigurationSourceProviderDetails'

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateConfigurationSourceProviderDetails.
        Human-readable name of the configuration source provider. Avoid entering confidential information.


        :return: The display_name of this UpdateConfigurationSourceProviderDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateConfigurationSourceProviderDetails.
        Human-readable name of the configuration source provider. Avoid entering confidential information.


        :param display_name: The display_name of this UpdateConfigurationSourceProviderDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this UpdateConfigurationSourceProviderDetails.
        Description of the configuration source provider. Avoid entering confidential information.


        :return: The description of this UpdateConfigurationSourceProviderDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateConfigurationSourceProviderDetails.
        Description of the configuration source provider. Avoid entering confidential information.


        :param description: The description of this UpdateConfigurationSourceProviderDetails.
        :type: str
        """
        self._description = description

    @property
    def config_source_provider_type(self):
        """
        Gets the config_source_provider_type of this UpdateConfigurationSourceProviderDetails.
        The type of configuration source provider.
        The `GITLAB_ACCESS_TOKEN` type corresponds to GitLab.
        The `GITHUB_ACCESS_TOKEN` type corresponds to GitHub.


        :return: The config_source_provider_type of this UpdateConfigurationSourceProviderDetails.
        :rtype: str
        """
        return self._config_source_provider_type

    @config_source_provider_type.setter
    def config_source_provider_type(self, config_source_provider_type):
        """
        Sets the config_source_provider_type of this UpdateConfigurationSourceProviderDetails.
        The type of configuration source provider.
        The `GITLAB_ACCESS_TOKEN` type corresponds to GitLab.
        The `GITHUB_ACCESS_TOKEN` type corresponds to GitHub.


        :param config_source_provider_type: The config_source_provider_type of this UpdateConfigurationSourceProviderDetails.
        :type: str
        """
        self._config_source_provider_type = config_source_provider_type

    @property
    def private_server_config_details(self):
        """
        Gets the private_server_config_details of this UpdateConfigurationSourceProviderDetails.

        :return: The private_server_config_details of this UpdateConfigurationSourceProviderDetails.
        :rtype: oci.resource_manager.models.PrivateServerConfigDetails
        """
        return self._private_server_config_details

    @private_server_config_details.setter
    def private_server_config_details(self, private_server_config_details):
        """
        Sets the private_server_config_details of this UpdateConfigurationSourceProviderDetails.

        :param private_server_config_details: The private_server_config_details of this UpdateConfigurationSourceProviderDetails.
        :type: oci.resource_manager.models.PrivateServerConfigDetails
        """
        self._private_server_config_details = private_server_config_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateConfigurationSourceProviderDetails.
        Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateConfigurationSourceProviderDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateConfigurationSourceProviderDetails.
        Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateConfigurationSourceProviderDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateConfigurationSourceProviderDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateConfigurationSourceProviderDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateConfigurationSourceProviderDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateConfigurationSourceProviderDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseParameterUpdateStatus(object):
    """
    The result of database parameter update.
    """

    #: A constant which can be used with the status property of a DatabaseParameterUpdateStatus.
    #: This constant has a value of "SUCCEEDED"
    STATUS_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the status property of a DatabaseParameterUpdateStatus.
    #: This constant has a value of "FAILED"
    STATUS_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseParameterUpdateStatus object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param status:
            The value to assign to the status property of this DatabaseParameterUpdateStatus.
            Allowed values for this property are: "SUCCEEDED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param error_code:
            The value to assign to the error_code property of this DatabaseParameterUpdateStatus.
        :type error_code: str

        :param error_message:
            The value to assign to the error_message property of this DatabaseParameterUpdateStatus.
        :type error_message: str

        """
        self.swagger_types = {
            'status': 'str',
            'error_code': 'str',
            'error_message': 'str'
        }

        self.attribute_map = {
            'status': 'status',
            'error_code': 'errorCode',
            'error_message': 'errorMessage'
        }

        self._status = None
        self._error_code = None
        self._error_message = None

    @property
    def status(self):
        """
        Gets the status of this DatabaseParameterUpdateStatus.
        The status of the parameter update.

        Allowed values for this property are: "SUCCEEDED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this DatabaseParameterUpdateStatus.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this DatabaseParameterUpdateStatus.
        The status of the parameter update.


        :param status: The status of this DatabaseParameterUpdateStatus.
        :type: str
        """
        allowed_values = ["SUCCEEDED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def error_code(self):
        """
        Gets the error_code of this DatabaseParameterUpdateStatus.
        An error code that defines the failure or `null` if the parameter
        was updated successfully.


        :return: The error_code of this DatabaseParameterUpdateStatus.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """
        Sets the error_code of this DatabaseParameterUpdateStatus.
        An error code that defines the failure or `null` if the parameter
        was updated successfully.


        :param error_code: The error_code of this DatabaseParameterUpdateStatus.
        :type: str
        """
        self._error_code = error_code

    @property
    def error_message(self):
        """
        Gets the error_message of this DatabaseParameterUpdateStatus.
        The error message indicating the reason for failure or `null` if
        the parameter was updated successfully.


        :return: The error_message of this DatabaseParameterUpdateStatus.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """
        Sets the error_message of this DatabaseParameterUpdateStatus.
        The error message indicating the reason for failure or `null` if
        the parameter was updated successfully.


        :param error_message: The error_message of this DatabaseParameterUpdateStatus.
        :type: str
        """
        self._error_message = error_message

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateHostInsightDetails(object):
    """
    The information about the host to be analyzed.
    """

    #: A constant which can be used with the entity_source property of a CreateHostInsightDetails.
    #: This constant has a value of "MACS_MANAGED_EXTERNAL_HOST"
    ENTITY_SOURCE_MACS_MANAGED_EXTERNAL_HOST = "MACS_MANAGED_EXTERNAL_HOST"

    #: A constant which can be used with the entity_source property of a CreateHostInsightDetails.
    #: This constant has a value of "EM_MANAGED_EXTERNAL_HOST"
    ENTITY_SOURCE_EM_MANAGED_EXTERNAL_HOST = "EM_MANAGED_EXTERNAL_HOST"

    #: A constant which can be used with the entity_source property of a CreateHostInsightDetails.
    #: This constant has a value of "PE_COMANAGED_HOST"
    ENTITY_SOURCE_PE_COMANAGED_HOST = "PE_COMANAGED_HOST"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateHostInsightDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.opsi.models.CreateMacsManagedExternalHostInsightDetails`
        * :class:`~oci.opsi.models.CreateEmManagedExternalHostInsightDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_source:
            The value to assign to the entity_source property of this CreateHostInsightDetails.
            Allowed values for this property are: "MACS_MANAGED_EXTERNAL_HOST", "EM_MANAGED_EXTERNAL_HOST", "PE_COMANAGED_HOST"
        :type entity_source: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateHostInsightDetails.
        :type compartment_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateHostInsightDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateHostInsightDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'entity_source': 'str',
            'compartment_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'entity_source': 'entitySource',
            'compartment_id': 'compartmentId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._entity_source = None
        self._compartment_id = None
        self._freeform_tags = None
        self._defined_tags = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['entitySource']

        if type == 'MACS_MANAGED_EXTERNAL_HOST':
            return 'CreateMacsManagedExternalHostInsightDetails'

        if type == 'EM_MANAGED_EXTERNAL_HOST':
            return 'CreateEmManagedExternalHostInsightDetails'
        else:
            return 'CreateHostInsightDetails'

    @property
    def entity_source(self):
        """
        **[Required]** Gets the entity_source of this CreateHostInsightDetails.
        Source of the host entity.

        Allowed values for this property are: "MACS_MANAGED_EXTERNAL_HOST", "EM_MANAGED_EXTERNAL_HOST", "PE_COMANAGED_HOST"


        :return: The entity_source of this CreateHostInsightDetails.
        :rtype: str
        """
        return self._entity_source

    @entity_source.setter
    def entity_source(self, entity_source):
        """
        Sets the entity_source of this CreateHostInsightDetails.
        Source of the host entity.


        :param entity_source: The entity_source of this CreateHostInsightDetails.
        :type: str
        """
        allowed_values = ["MACS_MANAGED_EXTERNAL_HOST", "EM_MANAGED_EXTERNAL_HOST", "PE_COMANAGED_HOST"]
        if not value_allowed_none_or_none_sentinel(entity_source, allowed_values):
            raise ValueError(
                "Invalid value for `entity_source`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._entity_source = entity_source

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateHostInsightDetails.
        Compartment Identifier of host


        :return: The compartment_id of this CreateHostInsightDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateHostInsightDetails.
        Compartment Identifier of host


        :param compartment_id: The compartment_id of this CreateHostInsightDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateHostInsightDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateHostInsightDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateHostInsightDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateHostInsightDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateHostInsightDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateHostInsightDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateHostInsightDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateHostInsightDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .decryption_profile import DecryptionProfile
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SslInboundInspectionProfile(DecryptionProfile):
    """
    SSLInboundInspection used on the firewall policy rules.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SslInboundInspectionProfile object with values from keyword arguments. The default value of the :py:attr:`~oci.network_firewall.models.SslInboundInspectionProfile.type` attribute
        of this class is ``SSL_INBOUND_INSPECTION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this SslInboundInspectionProfile.
            Allowed values for this property are: "SSL_INBOUND_INSPECTION", "SSL_FORWARD_PROXY"
        :type type: str

        :param is_unsupported_version_blocked:
            The value to assign to the is_unsupported_version_blocked property of this SslInboundInspectionProfile.
        :type is_unsupported_version_blocked: bool

        :param is_unsupported_cipher_blocked:
            The value to assign to the is_unsupported_cipher_blocked property of this SslInboundInspectionProfile.
        :type is_unsupported_cipher_blocked: bool

        :param is_out_of_capacity_blocked:
            The value to assign to the is_out_of_capacity_blocked property of this SslInboundInspectionProfile.
        :type is_out_of_capacity_blocked: bool

        """
        self.swagger_types = {
            'type': 'str',
            'is_unsupported_version_blocked': 'bool',
            'is_unsupported_cipher_blocked': 'bool',
            'is_out_of_capacity_blocked': 'bool'
        }

        self.attribute_map = {
            'type': 'type',
            'is_unsupported_version_blocked': 'isUnsupportedVersionBlocked',
            'is_unsupported_cipher_blocked': 'isUnsupportedCipherBlocked',
            'is_out_of_capacity_blocked': 'isOutOfCapacityBlocked'
        }

        self._type = None
        self._is_unsupported_version_blocked = None
        self._is_unsupported_cipher_blocked = None
        self._is_out_of_capacity_blocked = None
        self._type = 'SSL_INBOUND_INSPECTION'

    @property
    def is_unsupported_version_blocked(self):
        """
        **[Required]** Gets the is_unsupported_version_blocked of this SslInboundInspectionProfile.
        Whether to block sessions if SSL version is not supported.


        :return: The is_unsupported_version_blocked of this SslInboundInspectionProfile.
        :rtype: bool
        """
        return self._is_unsupported_version_blocked

    @is_unsupported_version_blocked.setter
    def is_unsupported_version_blocked(self, is_unsupported_version_blocked):
        """
        Sets the is_unsupported_version_blocked of this SslInboundInspectionProfile.
        Whether to block sessions if SSL version is not supported.


        :param is_unsupported_version_blocked: The is_unsupported_version_blocked of this SslInboundInspectionProfile.
        :type: bool
        """
        self._is_unsupported_version_blocked = is_unsupported_version_blocked

    @property
    def is_unsupported_cipher_blocked(self):
        """
        **[Required]** Gets the is_unsupported_cipher_blocked of this SslInboundInspectionProfile.
        Whether to block sessions if SSL cipher suite is not supported.


        :return: The is_unsupported_cipher_blocked of this SslInboundInspectionProfile.
        :rtype: bool
        """
        return self._is_unsupported_cipher_blocked

    @is_unsupported_cipher_blocked.setter
    def is_unsupported_cipher_blocked(self, is_unsupported_cipher_blocked):
        """
        Sets the is_unsupported_cipher_blocked of this SslInboundInspectionProfile.
        Whether to block sessions if SSL cipher suite is not supported.


        :param is_unsupported_cipher_blocked: The is_unsupported_cipher_blocked of this SslInboundInspectionProfile.
        :type: bool
        """
        self._is_unsupported_cipher_blocked = is_unsupported_cipher_blocked

    @property
    def is_out_of_capacity_blocked(self):
        """
        **[Required]** Gets the is_out_of_capacity_blocked of this SslInboundInspectionProfile.
        Whether to block sessions if the firewall is temporarily unable to decrypt their traffic.


        :return: The is_out_of_capacity_blocked of this SslInboundInspectionProfile.
        :rtype: bool
        """
        return self._is_out_of_capacity_blocked

    @is_out_of_capacity_blocked.setter
    def is_out_of_capacity_blocked(self, is_out_of_capacity_blocked):
        """
        Sets the is_out_of_capacity_blocked of this SslInboundInspectionProfile.
        Whether to block sessions if the firewall is temporarily unable to decrypt their traffic.


        :param is_out_of_capacity_blocked: The is_out_of_capacity_blocked of this SslInboundInspectionProfile.
        :type: bool
        """
        self._is_out_of_capacity_blocked = is_out_of_capacity_blocked

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DisApplication(object):
    """
    DIS Application is container for runtime objects.
    """

    #: A constant which can be used with the lifecycle_state property of a DisApplication.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a DisApplication.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a DisApplication.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a DisApplication.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a DisApplication.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a DisApplication.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new DisApplication object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this DisApplication.
        :type key: str

        :param model_type:
            The value to assign to the model_type property of this DisApplication.
        :type model_type: str

        :param model_version:
            The value to assign to the model_version property of this DisApplication.
        :type model_version: str

        :param name:
            The value to assign to the name property of this DisApplication.
        :type name: str

        :param description:
            The value to assign to the description property of this DisApplication.
        :type description: str

        :param application_version:
            The value to assign to the application_version property of this DisApplication.
        :type application_version: int

        :param object_status:
            The value to assign to the object_status property of this DisApplication.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this DisApplication.
        :type identifier: str

        :param parent_ref:
            The value to assign to the parent_ref property of this DisApplication.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param object_version:
            The value to assign to the object_version property of this DisApplication.
        :type object_version: int

        :param dependent_object_metadata:
            The value to assign to the dependent_object_metadata property of this DisApplication.
        :type dependent_object_metadata: list[oci.data_integration.models.PatchObjectMetadata]

        :param published_object_metadata:
            The value to assign to the published_object_metadata property of this DisApplication.
        :type published_object_metadata: dict(str, PatchObjectMetadata)

        :param source_application_info:
            The value to assign to the source_application_info property of this DisApplication.
        :type source_application_info: oci.data_integration.models.SourceApplicationInfo

        :param time_patched:
            The value to assign to the time_patched property of this DisApplication.
        :type time_patched: datetime

        :param id:
            The value to assign to the id property of this DisApplication.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DisApplication.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this DisApplication.
        :type display_name: str

        :param time_created:
            The value to assign to the time_created property of this DisApplication.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this DisApplication.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DisApplication.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DisApplication.
        :type defined_tags: dict(str, dict(str, object))

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DisApplication.
            Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param metadata:
            The value to assign to the metadata property of this DisApplication.
        :type metadata: oci.data_integration.models.ObjectMetadata

        :param key_map:
            The value to assign to the key_map property of this DisApplication.
        :type key_map: dict(str, str)

        """
        self.swagger_types = {
            'key': 'str',
            'model_type': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'application_version': 'int',
            'object_status': 'int',
            'identifier': 'str',
            'parent_ref': 'ParentReference',
            'object_version': 'int',
            'dependent_object_metadata': 'list[PatchObjectMetadata]',
            'published_object_metadata': 'dict(str, PatchObjectMetadata)',
            'source_application_info': 'SourceApplicationInfo',
            'time_patched': 'datetime',
            'id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'lifecycle_state': 'str',
            'metadata': 'ObjectMetadata',
            'key_map': 'dict(str, str)'
        }

        self.attribute_map = {
            'key': 'key',
            'model_type': 'modelType',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'application_version': 'applicationVersion',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'parent_ref': 'parentRef',
            'object_version': 'objectVersion',
            'dependent_object_metadata': 'dependentObjectMetadata',
            'published_object_metadata': 'publishedObjectMetadata',
            'source_application_info': 'sourceApplicationInfo',
            'time_patched': 'timePatched',
            'id': 'id',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'lifecycle_state': 'lifecycleState',
            'metadata': 'metadata',
            'key_map': 'keyMap'
        }

        self._key = None
        self._model_type = None
        self._model_version = None
        self._name = None
        self._description = None
        self._application_version = None
        self._object_status = None
        self._identifier = None
        self._parent_ref = None
        self._object_version = None
        self._dependent_object_metadata = None
        self._published_object_metadata = None
        self._source_application_info = None
        self._time_patched = None
        self._id = None
        self._compartment_id = None
        self._display_name = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None
        self._lifecycle_state = None
        self._metadata = None
        self._key_map = None

    @property
    def key(self):
        """
        Gets the key of this DisApplication.
        Generated key that can be used in API calls to identify application.


        :return: The key of this DisApplication.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this DisApplication.
        Generated key that can be used in API calls to identify application.


        :param key: The key of this DisApplication.
        :type: str
        """
        self._key = key

    @property
    def model_type(self):
        """
        Gets the model_type of this DisApplication.
        The object type.


        :return: The model_type of this DisApplication.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this DisApplication.
        The object type.


        :param model_type: The model_type of this DisApplication.
        :type: str
        """
        self._model_type = model_type

    @property
    def model_version(self):
        """
        Gets the model_version of this DisApplication.
        The object's model version.


        :return: The model_version of this DisApplication.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this DisApplication.
        The object's model version.


        :param model_version: The model_version of this DisApplication.
        :type: str
        """
        self._model_version = model_version

    @property
    def name(self):
        """
        Gets the name of this DisApplication.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this DisApplication.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DisApplication.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this DisApplication.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this DisApplication.
        Detailed description for the object.


        :return: The description of this DisApplication.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DisApplication.
        Detailed description for the object.


        :param description: The description of this DisApplication.
        :type: str
        """
        self._description = description

    @property
    def application_version(self):
        """
        Gets the application_version of this DisApplication.
        The application's version.


        :return: The application_version of this DisApplication.
        :rtype: int
        """
        return self._application_version

    @application_version.setter
    def application_version(self, application_version):
        """
        Sets the application_version of this DisApplication.
        The application's version.


        :param application_version: The application_version of this DisApplication.
        :type: int
        """
        self._application_version = application_version

    @property
    def object_status(self):
        """
        Gets the object_status of this DisApplication.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this DisApplication.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this DisApplication.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this DisApplication.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        Gets the identifier of this DisApplication.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this DisApplication.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this DisApplication.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this DisApplication.
        :type: str
        """
        self._identifier = identifier

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this DisApplication.

        :return: The parent_ref of this DisApplication.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this DisApplication.

        :param parent_ref: The parent_ref of this DisApplication.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def object_version(self):
        """
        Gets the object_version of this DisApplication.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this DisApplication.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this DisApplication.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this DisApplication.
        :type: int
        """
        self._object_version = object_version

    @property
    def dependent_object_metadata(self):
        """
        Gets the dependent_object_metadata of this DisApplication.
        A list of dependent objects in this patch.


        :return: The dependent_object_metadata of this DisApplication.
        :rtype: list[oci.data_integration.models.PatchObjectMetadata]
        """
        return self._dependent_object_metadata

    @dependent_object_metadata.setter
    def dependent_object_metadata(self, dependent_object_metadata):
        """
        Sets the dependent_object_metadata of this DisApplication.
        A list of dependent objects in this patch.


        :param dependent_object_metadata: The dependent_object_metadata of this DisApplication.
        :type: list[oci.data_integration.models.PatchObjectMetadata]
        """
        self._dependent_object_metadata = dependent_object_metadata

    @property
    def published_object_metadata(self):
        """
        Gets the published_object_metadata of this DisApplication.
        A list of objects that are published or unpublished in this patch.


        :return: The published_object_metadata of this DisApplication.
        :rtype: dict(str, PatchObjectMetadata)
        """
        return self._published_object_metadata

    @published_object_metadata.setter
    def published_object_metadata(self, published_object_metadata):
        """
        Sets the published_object_metadata of this DisApplication.
        A list of objects that are published or unpublished in this patch.


        :param published_object_metadata: The published_object_metadata of this DisApplication.
        :type: dict(str, PatchObjectMetadata)
        """
        self._published_object_metadata = published_object_metadata

    @property
    def source_application_info(self):
        """
        Gets the source_application_info of this DisApplication.

        :return: The source_application_info of this DisApplication.
        :rtype: oci.data_integration.models.SourceApplicationInfo
        """
        return self._source_application_info

    @source_application_info.setter
    def source_application_info(self, source_application_info):
        """
        Sets the source_application_info of this DisApplication.

        :param source_application_info: The source_application_info of this DisApplication.
        :type: oci.data_integration.models.SourceApplicationInfo
        """
        self._source_application_info = source_application_info

    @property
    def time_patched(self):
        """
        Gets the time_patched of this DisApplication.
        The date and time the application was patched, in the timestamp format defined by RFC3339.


        :return: The time_patched of this DisApplication.
        :rtype: datetime
        """
        return self._time_patched

    @time_patched.setter
    def time_patched(self, time_patched):
        """
        Sets the time_patched of this DisApplication.
        The date and time the application was patched, in the timestamp format defined by RFC3339.


        :param time_patched: The time_patched of this DisApplication.
        :type: datetime
        """
        self._time_patched = time_patched

    @property
    def id(self):
        """
        Gets the id of this DisApplication.
        OCID of the resource that is used to uniquely identify the application


        :return: The id of this DisApplication.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DisApplication.
        OCID of the resource that is used to uniquely identify the application


        :param id: The id of this DisApplication.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this DisApplication.
        OCID of the compartment that this resource belongs to. Defaults to compartment of the Workspace.


        :return: The compartment_id of this DisApplication.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DisApplication.
        OCID of the compartment that this resource belongs to. Defaults to compartment of the Workspace.


        :param compartment_id: The compartment_id of this DisApplication.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        Gets the display_name of this DisApplication.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The display_name of this DisApplication.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DisApplication.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param display_name: The display_name of this DisApplication.
        :type: str
        """
        self._display_name = display_name

    @property
    def time_created(self):
        """
        Gets the time_created of this DisApplication.
        The date and time the application was created, in the timestamp format defined by RFC3339.


        :return: The time_created of this DisApplication.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DisApplication.
        The date and time the application was created, in the timestamp format defined by RFC3339.


        :param time_created: The time_created of this DisApplication.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this DisApplication.
        The date and time the application was updated, in the timestamp format defined by RFC3339.
        example: 2019-08-25T21:10:29.41Z


        :return: The time_updated of this DisApplication.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this DisApplication.
        The date and time the application was updated, in the timestamp format defined by RFC3339.
        example: 2019-08-25T21:10:29.41Z


        :param time_updated: The time_updated of this DisApplication.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DisApplication.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this DisApplication.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DisApplication.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this DisApplication.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DisApplication.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this DisApplication.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DisApplication.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this DisApplication.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this DisApplication.
        The current state of the workspace.

        Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DisApplication.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DisApplication.
        The current state of the workspace.


        :param lifecycle_state: The lifecycle_state of this DisApplication.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def metadata(self):
        """
        Gets the metadata of this DisApplication.

        :return: The metadata of this DisApplication.
        :rtype: oci.data_integration.models.ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this DisApplication.

        :param metadata: The metadata of this DisApplication.
        :type: oci.data_integration.models.ObjectMetadata
        """
        self._metadata = metadata

    @property
    def key_map(self):
        """
        Gets the key_map of this DisApplication.
        A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.


        :return: The key_map of this DisApplication.
        :rtype: dict(str, str)
        """
        return self._key_map

    @key_map.setter
    def key_map(self, key_map):
        """
        Sets the key_map of this DisApplication.
        A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.


        :param key_map: The key_map of this DisApplication.
        :type: dict(str, str)
        """
        self._key_map = key_map

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HeatWaveCluster(object):
    """
    A HeatWave cluster is a database accelerator for a DB System.
    """

    #: A constant which can be used with the lifecycle_state property of a HeatWaveCluster.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a HeatWaveCluster.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a HeatWaveCluster.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a HeatWaveCluster.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a HeatWaveCluster.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a HeatWaveCluster.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a HeatWaveCluster.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new HeatWaveCluster object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param db_system_id:
            The value to assign to the db_system_id property of this HeatWaveCluster.
        :type db_system_id: str

        :param shape_name:
            The value to assign to the shape_name property of this HeatWaveCluster.
        :type shape_name: str

        :param cluster_size:
            The value to assign to the cluster_size property of this HeatWaveCluster.
        :type cluster_size: int

        :param cluster_nodes:
            The value to assign to the cluster_nodes property of this HeatWaveCluster.
        :type cluster_nodes: list[oci.mysql.models.HeatWaveNode]

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this HeatWaveCluster.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this HeatWaveCluster.
        :type lifecycle_details: str

        :param time_created:
            The value to assign to the time_created property of this HeatWaveCluster.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this HeatWaveCluster.
        :type time_updated: datetime

        """
        self.swagger_types = {
            'db_system_id': 'str',
            'shape_name': 'str',
            'cluster_size': 'int',
            'cluster_nodes': 'list[HeatWaveNode]',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime'
        }

        self.attribute_map = {
            'db_system_id': 'dbSystemId',
            'shape_name': 'shapeName',
            'cluster_size': 'clusterSize',
            'cluster_nodes': 'clusterNodes',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated'
        }

        self._db_system_id = None
        self._shape_name = None
        self._cluster_size = None
        self._cluster_nodes = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._time_created = None
        self._time_updated = None

    @property
    def db_system_id(self):
        """
        **[Required]** Gets the db_system_id of this HeatWaveCluster.
        The OCID of the parent DB System this HeatWave cluster is attached to.


        :return: The db_system_id of this HeatWaveCluster.
        :rtype: str
        """
        return self._db_system_id

    @db_system_id.setter
    def db_system_id(self, db_system_id):
        """
        Sets the db_system_id of this HeatWaveCluster.
        The OCID of the parent DB System this HeatWave cluster is attached to.


        :param db_system_id: The db_system_id of this HeatWaveCluster.
        :type: str
        """
        self._db_system_id = db_system_id

    @property
    def shape_name(self):
        """
        **[Required]** Gets the shape_name of this HeatWaveCluster.
        The shape determines resources to allocate to the HeatWave
        nodes - CPU cores, memory.


        :return: The shape_name of this HeatWaveCluster.
        :rtype: str
        """
        return self._shape_name

    @shape_name.setter
    def shape_name(self, shape_name):
        """
        Sets the shape_name of this HeatWaveCluster.
        The shape determines resources to allocate to the HeatWave
        nodes - CPU cores, memory.


        :param shape_name: The shape_name of this HeatWaveCluster.
        :type: str
        """
        self._shape_name = shape_name

    @property
    def cluster_size(self):
        """
        **[Required]** Gets the cluster_size of this HeatWaveCluster.
        The number of analytics-processing compute instances, of the
        specified shape, in the HeatWave cluster.


        :return: The cluster_size of this HeatWaveCluster.
        :rtype: int
        """
        return self._cluster_size

    @cluster_size.setter
    def cluster_size(self, cluster_size):
        """
        Sets the cluster_size of this HeatWaveCluster.
        The number of analytics-processing compute instances, of the
        specified shape, in the HeatWave cluster.


        :param cluster_size: The cluster_size of this HeatWaveCluster.
        :type: int
        """
        self._cluster_size = cluster_size

    @property
    def cluster_nodes(self):
        """
        **[Required]** Gets the cluster_nodes of this HeatWaveCluster.
        A HeatWave node is a compute host that is part of a HeatWave cluster.


        :return: The cluster_nodes of this HeatWaveCluster.
        :rtype: list[oci.mysql.models.HeatWaveNode]
        """
        return self._cluster_nodes

    @cluster_nodes.setter
    def cluster_nodes(self, cluster_nodes):
        """
        Sets the cluster_nodes of this HeatWaveCluster.
        A HeatWave node is a compute host that is part of a HeatWave cluster.


        :param cluster_nodes: The cluster_nodes of this HeatWaveCluster.
        :type: list[oci.mysql.models.HeatWaveNode]
        """
        self._cluster_nodes = cluster_nodes

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this HeatWaveCluster.
        The current state of the HeatWave cluster.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this HeatWaveCluster.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this HeatWaveCluster.
        The current state of the HeatWave cluster.


        :param lifecycle_state: The lifecycle_state of this HeatWaveCluster.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this HeatWaveCluster.
        Additional information about the current lifecycleState.


        :return: The lifecycle_details of this HeatWaveCluster.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this HeatWaveCluster.
        Additional information about the current lifecycleState.


        :param lifecycle_details: The lifecycle_details of this HeatWaveCluster.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this HeatWaveCluster.
        The date and time the HeatWave cluster was created,
        as described by `RFC 3339`__.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_created of this HeatWaveCluster.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this HeatWaveCluster.
        The date and time the HeatWave cluster was created,
        as described by `RFC 3339`__.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_created: The time_created of this HeatWaveCluster.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this HeatWaveCluster.
        The time the HeatWave cluster was last updated,
        as described by `RFC 3339`__.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_updated of this HeatWaveCluster.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this HeatWaveCluster.
        The time the HeatWave cluster was last updated,
        as described by `RFC 3339`__.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_updated: The time_updated of this HeatWaveCluster.
        :type: datetime
        """
        self._time_updated = time_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .database_upgrade_source_base import DatabaseUpgradeSourceBase
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseUpgradeWithDatabaseSoftwareImageDetails(DatabaseUpgradeSourceBase):
    """
    Details of the database software image to be used to upgrade a database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseUpgradeWithDatabaseSoftwareImageDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database.models.DatabaseUpgradeWithDatabaseSoftwareImageDetails.source` attribute
        of this class is ``DB_SOFTWARE_IMAGE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source:
            The value to assign to the source property of this DatabaseUpgradeWithDatabaseSoftwareImageDetails.
            Allowed values for this property are: "DB_HOME", "DB_VERSION", "DB_SOFTWARE_IMAGE"
        :type source: str

        :param options:
            The value to assign to the options property of this DatabaseUpgradeWithDatabaseSoftwareImageDetails.
        :type options: str

        :param database_software_image_id:
            The value to assign to the database_software_image_id property of this DatabaseUpgradeWithDatabaseSoftwareImageDetails.
        :type database_software_image_id: str

        """
        self.swagger_types = {
            'source': 'str',
            'options': 'str',
            'database_software_image_id': 'str'
        }

        self.attribute_map = {
            'source': 'source',
            'options': 'options',
            'database_software_image_id': 'databaseSoftwareImageId'
        }

        self._source = None
        self._options = None
        self._database_software_image_id = None
        self._source = 'DB_SOFTWARE_IMAGE'

    @property
    def database_software_image_id(self):
        """
        **[Required]** Gets the database_software_image_id of this DatabaseUpgradeWithDatabaseSoftwareImageDetails.
        The database software image `OCID`__ of the image to be used to upgrade a database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The database_software_image_id of this DatabaseUpgradeWithDatabaseSoftwareImageDetails.
        :rtype: str
        """
        return self._database_software_image_id

    @database_software_image_id.setter
    def database_software_image_id(self, database_software_image_id):
        """
        Sets the database_software_image_id of this DatabaseUpgradeWithDatabaseSoftwareImageDetails.
        The database software image `OCID`__ of the image to be used to upgrade a database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param database_software_image_id: The database_software_image_id of this DatabaseUpgradeWithDatabaseSoftwareImageDetails.
        :type: str
        """
        self._database_software_image_id = database_software_image_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
